==> firefly-3.2.1.tar.gz: firefly-3.2.1/README.md <==

# Firefly

[![PyPI](https://img.shields.io/pypi/v/Firefly)](https://pypi.org/project/Firefly)
<a href="https://ascl.net/1810.021"><img src="https://img.shields.io/badge/ascl-1810.021-blue.svg?colorB=262255" alt="ascl:1810.021" /></a>

![logo banner](https://github.com/ageller/Firefly/blob/main/docs/source/_static/four_view_banner.png?raw=true)


Firefly is an interactive viewer for any particle-based data. A live example is available [here](https://ageller.github.io/Firefly/)
or if you're ready to get started creating your own interactive viewer, [click here](https://alexbgurvi.ch/Firefly/docs/build/html/data_reader/index.html).

If you use Firefly, please cite us using the [ADS listing](http://adsabs.harvard.edu/abs/2018ascl.soft10021G) that points to our Astrophysics Source Code Library (ASCL) entry.

## Additional Docs

Comprehensive documentation is available [here](http://alexbgurvi.ch/Firefly/docs/build/html/index.html).

## Contributors 
### Primary Developers
* Aaron Geller
* Alex Gurvich
### Past Contributors 
* Mike Cronin
* Zach Hafen
* Alessandro Febretti
### Student Contributors
* Mahlet Shiferaw 
* Luolei Zhao
* Nora Linzer
### Project PI
* Claude-André Faucher-Giguère 


## Acknowledgments
Firefly is written in WebGL using the three.js library.
This tool builds off of a [previous version developed by Alessandro Febretti](https://github.com/nuitrcs/firefly). 

This project is funded by [Northwestern's Center for Interdisciplinary Exploration and Research in Astrophysics (CIERA)](https://ciera.northwestern.edu/),  [Northwestern's IT Research Computing group](https://www.it.northwestern.edu/research/index.html), and NSF grants AST-1412836, AST-1715216, and CAREER award AST-1652522 awarded to [Claude-André Faucher-Giguère](https://www.physics.northwestern.edu/people/faculty/core-faculty/claude-andre-faucher-giguere.html).


## Additional Info
Firefly was originally designed for [FIRE](http://galaxies.northwestern.edu/fire-simulations/) data, but has since been extended to support any particle data.
This package should not be confused with the serendipitously named web-based visualization software [Firefly, from Caltech-IPAC](https://github.com/Caltech-IPAC/firefly), a general tool for retrieving and viewing astronomy data.

==> firefly-3.2.2.tar.gz: firefly-3.2.2/README.md <==

# Firefly

[![PyPI](https://img.shields.io/pypi/v/Firefly)](https://pypi.org/project/Firefly)
<a href="https://ascl.net/1810.021"><img src="https://img.shields.io/badge/ascl-1810.021-blue.svg?colorB=262255" alt="ascl:1810.021" /></a>

![logo banner](https://github.com/ageller/Firefly/blob/main/docs/source/_static/four_view_banner.png?raw=true)


Firefly is an interactive viewer for any particle-based data. A live example is available [here](https://ageller.github.io/Firefly/)
or if you're ready to get started creating your own interactive viewer, [click here](http://www.firefly-viz.com/docs/data_reader).

If you use Firefly, please cite us using the [ADS listing](http://adsabs.harvard.edu/abs/2018ascl.soft10021G) that points to our Astrophysics Source Code Library (ASCL) entry.

## Additional Docs

Comprehensive documentation is available [here](http://www.firefly-viz.com/docs).

## Contributors 
### Primary Developers
* Aaron Geller
* Alex Gurvich
### Past Contributors 
* Mike Cronin
* Zach Hafen
* Alessandro Febretti
### Student Contributors
* Mahlet Shiferaw 
* Luolei Zhao
* Nora Linzer
### Project PI
* Claude-André Faucher-Giguère 


## Acknowledgments
Firefly is written in WebGL using the three.js library.
This tool builds off of a [previous version developed by Alessandro Febretti](https://github.com/nuitrcs/firefly). 

This project is funded by [Northwestern's Center for Interdisciplinary Exploration and Research in Astrophysics (CIERA)](https://ciera.northwestern.edu/),  [Northwestern's IT Research Computing group](https://www.it.northwestern.edu/research/index.html), and NSF grants AST-1412836, AST-1715216, and CAREER award AST-1652522 awarded to [Claude-André Faucher-Giguère](https://www.physics.northwestern.edu/people/faculty/core-faculty/claude-andre-faucher-giguere.html).


## Additional Info
Firefly was originally designed for [FIRE](http://galaxies.northwestern.edu/fire-simulations/) data, but has since been extended to support any particle data.
This package should not be confused with the serendipitously named web-based visualization software [Firefly, from Caltech-IPAC](https://github.com/Caltech-IPAC/firefly), a general tool for retrieving and viewing astronomy data.
